import matplotlib.pyplot as plt
import numpy as np
import theory as th
import os, sys
lib_path = os.path.abspath(os.path.join('..', 'modules'))
sys.path.append(lib_path)
import graph 

graph.smallsettings()

def makearrowheads(fig, ax):
    xmin, xmax = ax.get_xlim()
    ymin, ymax = ax.get_ylim()
    for side in ['bottom','right','top','left']:
        ax.spines[side].set_visible(False)
    plt.xticks([])  
    plt.yticks([])
    ax.xaxis.set_ticks_position('none') 
    ax.yaxis.set_ticks_position('none')
    dps = fig.dpi_scale_trans.inverted()
    bbox = ax.get_window_extent().transformed(dps)
    width, height = bbox.width, bbox.height
    hw = 1./40.*(ymax-ymin) 
    hl = 1./40.*(xmax-xmin)
    lw = 2. 
    ohg = 0. 
     
    yhw = hw/(ymax-ymin)*(xmax-xmin)* height/width 
    yhl = hl/(xmax-xmin)*(ymax-ymin)* width/height
     
    ax.arrow(xmin, 0, xmax-xmin, 0., fc='k', ec='k', lw = lw, 
             head_width=hw, head_length=hl, overhang = ohg, 
             length_includes_head= True, clip_on = False) 
     
    ax.arrow(0, 0, 0., ymax, fc='k', ec='k', lw = lw, 
             head_width=yhw, head_length=yhl, overhang = ohg, 
             length_includes_head= True, clip_on = False) 

def labels(ax, direction='forward'):
    fs = 24
    if direction=='forward':
        yl = r'$|S_{21}|^2$'
    else:
        yl = r'$|S_{12}|^2$'
    ax.text(0, 1.05* ax.get_ylim()[1], yl, fontsize=fs, 
            horizontalalignment='center')
    ax.text(1.025*ax.get_xlim()[1], 0, r'$\omega$', fontsize=fs, 
            verticalalignment='center')

figopts = {
        'figsize':(4., 2.5)
        }
options = {
    'lw':4,
    'ls':'--',
    'zorder':1,
    }
options_sum = {
    'lw':2,
    'zorder':1,
    }

def lorentzian(om, delt, width=1):
    return 1./(0.5 *width + 1j*(delt -om))

oms = np.linspace(0,10, 101)
left=4
right=6
ampls = np.abs(lorentzian(oms, left, 2))**2
ampls2 = np.abs(lorentzian(oms, right, 2))**2

A = lorentzian(oms, left, 2)
B = lorentzian(oms, right, 2)
mid = len(A)//2
phase = np.angle(-B[mid]/A[mid])
ratio = np.log(ampls/ampls2)
factor = 0.5 + 0.5 * (ratio / max(ratio))
factor1 = np.sqrt(factor)
factor2 = np.sqrt(1-factor)

def interference(arm1, arm2):
    return np.abs(arm1*factor1 + arm2 * factor2)**2

backward = interference(A, np.exp(-1j*phase)* B)
forward = interference(A, np.exp(1j*phase)* B)
names = ('forward', 'backward')

oms = np.linspace(-5,5, 201)
ampls = th.S21(oms, onlyone='l')
ampls2 = th.S21(oms, onlyone='r')
forward = th.S21(oms)
backward = th.S12(oms)
oms = oms + 5

top = max(np.concatenate((forward, backward)))
top_susc = max(np.concatenate((ampls, ampls2)))

for dat, name in zip((forward, backward), names):
    fig, ax = plt.subplots(**figopts)
    ax.plot(oms, ampls, color='#78b626', **options)
    ax.plot(oms, ampls2, color='#577c66', **options)
    ax.plot(oms, dat, color='black', **options_sum)
    ax.set_ylim((0, top*1.05))
    ax.set_xlim((0, max(oms)))
    dashed = dict(color='gray', ls='--', lw=0.5, zorder=0)
    ax.plot([left, left], [0, top_susc], **dashed)
    ax.plot([right, right], [0, top_susc], **dashed)
    arrowheight = -0.05*top 
    ax.annotate('', 
            xy=(left, arrowheight), xycoords='data',
            xytext=(right, arrowheight), textcoords='data',
            arrowprops=dict(arrowstyle='<->'),
            annotation_clip=False)
    ax.annotate('$2\delta$', 
            xy=(0.5*(left+right), arrowheight*1.5), xycoords='data',
            fontsize=3*8, ha='center', va='top',
            annotation_clip=False)
    labels(ax, direction=name)
    makearrowheads(fig, ax)
    fig.savefig('inter_{}.pdf'.format(name), bbox_inches='tight')
    plt.close(fig)

plt.close(fig)
