import numpy as np
import glob
import os, sys
lib_path = os.path.abspath(os.path.join('..', 'modules'))
sys.path.append(lib_path)
from graph import graph
import getdata as gd

datadirs = [
        'data/122846_nonreciprocity',
        'data/075624_nonreciprocity',
        'data/220538_nonreciprocity',
        ]

fisi = (1.5*1.2, 1.5*0.7)
S21_col = '#c65102'
S12_col = '#0a888a'

for i, datadir in enumerate(datadirs):
    phase = gd.get_a_b(datadir, 'src3', 'phase')
    data = np.loadtxt(gd.get_setdat(datadir))

    detunings = data[:,0]
    S21_sq = data[:,2]
    S12_sq = data[:,3]

    # calibrated insertion losses
    alpha_bright = 0.66
    alpha_dark = 3.64
    # approximate value used in dataset
    alpha_dataset = 1.6

    S21_sq = S21_sq + alpha_dataset - alpha_dark
    S12_sq = S12_sq + alpha_dataset - alpha_bright

    if i==0:
        otherfunc = lambda fig,ax: fig.set_size_inches(*fisi)
    else:
        def otherfunc(fig, ax):
            fig.set_size_inches(*fisi)
            ax.get_yaxis().set_ticklabels([])
            ax.set_ylabel('')

    graph(
            [detunings]*2, [S21_sq, S12_sq],
            'slice_{:.2f}.pdf'.format(phase),
            xlab = 'Probe detuning (kHz)',
            ylab = 'Transmission (dB)',
            xrange = [min(detunings), max(detunings)],
            yrange = [-40, 0],
            small=True,
            colors = [S21_col, S12_col],
            otherfunc=otherfunc,
            )

def of(fig, ax):
    ax.set_axis_off(),
    fig.set_size_inches((0.2, 0.5))
graph(
        [0, 0], [0,0],
        'slices_legend.pdf',
        small=True,
        legends = ['$|S_{21}|^2$', '$|S_{12}|^2$'],
        colors = [S21_col, S12_col],
        otherfunc=of,
        )

