import matplotlib.pyplot as plt
import numpy as np
import os, sys
lib_path = os.path.abspath(os.path.join('..', 'modules'))
sys.path.append(lib_path)
import graph 
graph.smallsettings()

fisi = (3, 1.3)

xlab = 'Pump phase $\phi_\mathrm{p}$ (radians)'
ylab = 'Probe detuning (kHz)'
clab = '$|S_{21}/S_{12}|^2$ (dB)'

def colormap(Z, gname, ran,   
        cmap='RdBu_r', lims=None, vslices=[], 
        hide_cbar=False, hide_ylabs=False):
    options = {
            'aspect':'auto',
            'origin':'lower',
            'extent':ran,
            'interpolation':'none',
            'vmin':-25,
            'vmax':25,
            }
    fig, ax = plt.subplots(figsize=fisi)
    fig.subplots_adjust(0,0,1,1)
    plotamp = ax.imshow(Z, **options)
    plotamp.set_cmap(cmap)
    cbar = plt.colorbar(plotamp, shrink=1)
    cbar.set_label(clab)
    ax.set_xticks([-np.pi, -0.5*np.pi, 0, 0.5*np.pi, np.pi])
    ax.set_xticklabels(['$-\pi$', '$-\pi/2$', '0', '$\pi/2$', '$\pi$'])
    if hide_cbar:
        cbar.remove()
    ax.set_xlabel(xlab)
    ax.set_ylabel(ylab)
    if hide_ylabs:
        ax.yaxis.set_ticklabels([])
        ax.set_ylabel('')
    if lims:
        ax.set_xlim((lims[0], lims[1]))
        ax.set_ylim((lims[2], lims[3]))
    for vslice in vslices:
        ax.plot((vslice, vslice), ax.get_ylim(),
                '--', color='grey', lw=0.5,
                )
        
    fig.savefig(gname + '.pdf', bbox_inches='tight')

