import numpy as np
import matplotlib.pyplot as plt
import glob
import os, sys
lib_path = os.path.abspath(os.path.join('..', 'modules'))
sys.path.append(lib_path)
import getdata as gd
from NR_cmap import colormap

# calibrated insertion loss
alpha_bright = 0.66
alpha_dark = 3.64
delta_alpha = alpha_dark - alpha_bright

def colorplot(data, name, vmin=None, vmax=None, LA=False,
        nxkeep=None, nykeep=None, omit=None, roll=None,
        vslices=[]):
    def imreshape(col):
        Z = (col.reshape(nx, ny))
        if omit:
            inds = np.array(range(nx))
            inds = np.logical_and(inds>omit[0], inds<omit[1])
            inds = np.tile(inds, (ny,1)).transpose()
            Z = np.ma.masked_where(inds, Z)
        if nxkeep is not None:
            Z = Z[nxkeep[0]:nxkeep[1]]
        if nykeep is not None:
            Z = Z[:,nykeep[0]:nykeep[1]]
        Z = Z.T
        if roll:
            Z = np.roll(Z, roll)
        return Z

    pumpphase = imreshape(data[:,0])
    vnapoints = imreshape(data[:,1])
    vnamid = (vnapoints.min() + vnapoints.max())/2.0
    vnamin = (vnapoints.min()-vnamid)
    vnamax = (vnapoints.max()-vnamid)
    ran = (pumpphase.min(), pumpphase.max(), vnamin, vnamax)

    graphbn = name

    Zamp = imreshape(data[:,2])
    Zamp = Zamp - delta_alpha
    colormap(Zamp, graphbn + '_colormap', ran,
            lims=lims, vslices=vslices,
            hide_cbar=True)

if __name__ == '__main__':
    datadir =  'data/095835_Non-reciprocity_phase_sweep'
    data = np.loadtxt(sorted(glob.glob(datadir + '/*.dat'))[0])

    ny = 501
    nx = len(data)/ny 

    lims= None
    colorplot(data, 'data',
            vslices=[-2.52, 0, 2.56])


