import numpy as np
import matplotlib.pyplot as plt
import glob
import NR_cmap as NRC
import os, sys
lib_path = os.path.abspath(os.path.join('..', 'modules'))
sys.path.append(lib_path)
import getdata as gd
import graph as graph

graph.smallsettings()

k1 = 2 * np.pi * 200
k1Ex = 2 * np.pi * 150
k2 = 2 * np.pi * 3300
k2Ex = 2 * np.pi * 3000
gammaG = 2 * np.pi * 20
gammaH = 2 * np.pi * 10*1e-3
g1 = np.sqrt(0.78 * k1 * gammaG / 4.0)
g2 = np.sqrt(0.68 * k2 * gammaG / 4.0)
h1 = np.sqrt(1350 * k1 * gammaH / 4.0)
h2 = np.sqrt(1280 * k2 * gammaH / 4.0)
delta = 2 * np.pi * 18

def S12(w, p):
    A = np.sqrt(k1Ex) * np.sqrt(k2Ex) * (
            1j * delta * np.exp(-1j*p) * g1 * g2
            + 0.5 * np.exp(-1j*p) * g1 * g2 * gammaH
            - 1j * delta * h1 * h2
            + 0.5 * gammaG * h1 * h2
            - 1j * np.exp(-1j*p) * g1 * g2 * w
            - 1j * h1 * h2 * w
            )
    B = 1j * h1 * (
            - 1j * g2**2 * h1
            + 1j * np.exp(-1j*p) * g1*g2*h2
            - 0.5 * delta * h1 * k2
            - 0.25 * 1j * gammaG * h1 * k2
            + 1j * delta * h1 * w
            - 0.5 * gammaG * h1 * w
            - 0.5 * h1 * k2 * w
            + 1j * h1 * w**2
            )
    C = -1j * h2 * (
            - 1j * np.exp(1j*p) * g1 * g2 * h1
            + 1j * g1**2 * h2
            + 0.5 * delta * h2 * k1
            + 0.25 * 1j * gammaG * h2 * k1
            - 1j * delta * h2 * w
            + 0.5 * gammaG * h2 * w
            + 0.5 * h2 * k1 * w
            - 1j * h2 * w**2
            )
    D = (-1j * delta - 0.5 * gammaH + 1j * w) * (
            1j * g2 * (0.5 * 1j * g2 * k1 + g2 * w)
            + (-0.5*k2 + 1j *w) * (
                g1**2
                - 0.5*1j * delta * k1
                + 0.25 * gammaG * k1
                - delta * w
                - 1j * 0.5 * gammaG * w
                - 1j * 0.5 * k1 * w
                - w**2
                )
            )
    return np.abs(A / (B + C + D))

def S21(w, p):
    return S12(w, -p)

def nonrep(w, p):
    return 20*np.log10(np.abs(S12(w,p)/S21(w,p)))

phases = np.linspace(-np.pi, np.pi, 501)
freqs = np.linspace(-50, 50, 501)
X, Y = np.meshgrid(phases, freqs)

Z = nonrep(2 * np.pi * (Y - 7.5), -X + np.pi)

ran = (phases.min(), phases.max(), freqs[0], freqs[-1])

NRC.colormap(Z, 'theory_colormap', ran,
        hide_cbar=False, hide_ylabs=True,
        )


