import matplotlib.pyplot as plt
import numpy as np
import theory as th
import os, sys
lib_path = os.path.abspath(os.path.join('..', 'modules'))
sys.path.append(lib_path)
import graph

graph.smallsettings()

color_direct = '#f26333'
color_other = '#f0cf10'
fisi = (2.5, 1.9)

alw = 1.5
tlw = 2.5
nlw = 1.5

yar_fac = 0.9

def makearrowheads(fig, ax):
    xmin, xmax = ax.get_xlim()
    ymin, ymax = ax.get_ylim()
    for side in ['bottom','right','top','left']:
        ax.spines[side].set_visible(False)
    plt.xticks([])  
    plt.yticks([])
    ax.xaxis.set_ticks_position('none') 
    ax.yaxis.set_ticks_position('none')
    dps = fig.dpi_scale_trans.inverted()
    bbox = ax.get_window_extent().transformed(dps)
    width, height = bbox.width, bbox.height
    hw = 1./40.*(ymax-ymin) 
    hl = 1./40.*(xmax-xmin)
    lw = alw 
    ohg = 0. 
     
    yhw = hw/(ymax-ymin)*(xmax-xmin)* height/width 
    yhl = hl/(xmax-xmin)*(ymax-ymin)* width/height
     
    ax.arrow(xmin, 0, xmax-xmin, 0., fc='k', ec='k', lw = lw, 
             head_width=hw, head_length=hl, overhang = ohg, 
             length_includes_head= True, clip_on = False) 
     
    ax.arrow(0, 0, 0., yar_fac*ymax, fc='k', ec='k', lw = lw, 
             head_width=yhw, head_length=yhl, overhang = ohg, 
             length_includes_head= True, clip_on = False) 

def labels(ax, direction='forward'):
    fs = 12
    if direction=='forward':
        yl = r'${N}_\mathrm{fw}^{(\hat b_2)}$'
    else:
        yl = r'${N}_\mathrm{bw}^{(\hat b_2)}$'
    ax.text(0, yar_fac* 1.05* ax.get_ylim()[1], yl, 
            fontsize=fs, horizontalalignment='center')
    ax.text(1.025*ax.get_xlim()[1], 0, r'$\omega$', 
            fontsize=fs, verticalalignment='center')

figopts = {
        'figsize':fisi
        }
options = {
    'lw':tlw,
    'ls':'--',
    'zorder':1,
    }
options_sum = {
    'lw':nlw,
    'zorder':1,
    }

hspan = 100
oms = np.linspace(-hspan, hspan, 201) 
realigned = np.linspace(0, 10, len(oms))
phi = -np.arccos(1 - 1/th.C1)

fordat = [
    map(lambda om: th.noise_transm(th.direct_path(om, phi)), oms),
    map(lambda om: th.noise_transm(th.other_mod_path(om, phi)), oms),
    map(lambda om: th.noise_transm(
        th.other_path(om, phi) + th.direct_path(om, phi)), oms),
    ]

backdat = [
    map(lambda om: th.noise_transm(th.direct_path(om, -phi)), oms), 
    map(lambda om: th.noise_transm(th.other_mod_path(om, -phi)), oms),
    map(lambda om: th.noise_transm(
        th.other_path(om, -phi) + th.direct_path(om, -phi)), oms), 
    ]

top = max(np.concatenate((fordat[2], backdat[2])))

scale = lambda n: np.log10(n) + 2.2
names = ('forward', 'backward')
for datas, name in zip((fordat, backdat), names):
    fig, ax = plt.subplots(**figopts)
    ax.plot(realigned, scale(datas[0]), color=color_direct, **options)
    ax.plot(realigned, scale(datas[1]), color=color_other, **options)
    ax.plot(realigned, scale(datas[2]), color='black', **options_sum)
    ax.set_ylim((0, scale(top)*1.05))
    ax.set_xlim((0, max(realigned)))
    dashed = dict(color='gray', ls='--', lw=0.5, zorder=0)
    labels(ax, direction=name)
    makearrowheads(fig, ax)
    fig.savefig('noise_{}.pdf'.format(name), bbox_inches='tight')
    plt.close(fig)

plt.close(fig)

