import os, sys
lib_path = os.path.abspath(os.path.join('..', 'modules'))
sys.path.append(lib_path)
import getdata as gd
import numpy as np

# attenuation in dB at each port
# Calibrated insertion loss for the second chip
alpha_dark = 2.95 
alpha_bright = 1.26

# calibrated HEMT noise T in K
T_4_0854 = 4.2057
T_5_1954 = 4.4731

def Nquanta(T, f):
    h = 6.62607e-34
    kB = 1.3806e-23
    return kB*T / (h*f)

n_dark = Nquanta(T_4_0854, 4.0854e9)
n_bright = Nquanta(T_5_1954, 5.1954e9)

def normalize_noise(P_dBmpHz, HEMTleveldBmpHz, nHEMT, alpha):
    P_mW = 10**(P_dBmpHz/10.0)
    HEMTlevel_mW = 10**(HEMTleveldBmpHz/10.0)
    HEMTlevel_mW_avg = HEMTlevel_mW.mean()
    P_atHEMT = P_mW - HEMTlevel_mW
    P_quanta = nHEMT * (P_atHEMT/HEMTlevel_mW_avg)
    P_out = P_quanta  * 10**(alpha/10.0)
    return P_out

def normnoise_dark(datadir, HEMTLev_dark):
    freqs, fswpowers, params = gd.getFSWdata(datadir, dBmHz=True)
    return normalize_noise(fswpowers, HEMTLev_dark, n_dark, alpha_dark)
def normnoise_bright(datadir, HEMTLev_bright):
    freqs, fswpowers, params = gd.getFSWdata(datadir, dBmHz=True)
    return normalize_noise(fswpowers, HEMTLev_bright, n_bright, alpha_bright)

def get_freqs(datadir):
    freqs, fswpowers, params = gd.getFSWdata(datadir, dBmHz=True)
    return freqs

def measure_background(datafolder):
    freqs, fswpowers, params = gd.getFSWdata(datafolder, dBmHz=True)
    BG_dBmHz = fswpowers
    return BG_dBmHz


