import theory_circulator as tc
import numpy as np
import os, sys
lib_path = os.path.abspath(os.path.join('..', 'modules'))
sys.path.append(lib_path)
from graph import graph

col_f = 'xkcd:raspberry'
col_b = 'xkcd:denim'
col_n = 'xkcd:tangerine'
fisi = (1.2, 0.9)

betas = [10., 100., 1000.]
coops = [100., 1000.]
fs = np.linspace(-180., 180., 201)

M, L = tc.matrices(10)

for coop in coops:
    S = [ tc.S_matrix_coop(f, coop) for f in fs]
    forward = [ 20*np.log10(np.abs(sm[1,0])) for sm in S]
    backward = [ 20*np.log10(np.abs(sm[0,1])) for sm in S]
    noise = [ tc.noiseout(sm) for sm in S]
    if coop==100.0:
        def otherfunc(fig, ax): 
            fig.set_size_inches(*fisi)
            ax.locator_params(axis='x', nbins=3)
    else:
        def otherfunc(fig, ax):
            fig.set_size_inches(*fisi)
            ax.get_yaxis().set_ticklabels([])
            ax.set_ylabel('')
            ax.locator_params(axis='x', nbins=3)
    graph(
            [fs]*2, [forward, backward],
            'transmission_{:.0f}.pdf'.format(coop),
            xlab = 'Probe detuning (kHz)',
            ylab = 'Transmission (dB)',
            xrange = [min(fs), max(fs)],
            yrange = [-30, 0],
            small=True,
            fisi=fisi,
            colors = [col_f, col_b],
            otherfunc=otherfunc,
            )
    graph(
            [fs], [noise],
            'noise_{:.0f}.pdf'.format(coop),
            xlab = 'Probe detuning (kHz)',
            ylab = '$N$ (quanta/ (s Hz))',
            xrange = [min(fs), max(fs)],
            yrange = [0, 10],
            small=True,
            fisi=fisi,
            colors = [col_n],
            otherfunc=otherfunc,
            )

def of(fig, ax):
    ax.set_axis_off(),
    handles, labels = ax.get_legend_handles_labels()
    fig.set_size_inches((0.2, 0.5))
graph(
        [0, 0], [0,0],
        'transmission_legends.pdf',
        small=True,
        legends = ['$|S_{\mathrm{ccw}}|^2$', '$|S_{\mathrm{cw}}|^2$'],
        colors = [col_f, col_b],
        otherfunc=of,
        )

