import numpy as np

tau = 2 * np.pi

# dissipation rates
k1 = tau * 200
k2 = tau * 200
k3 = tau * 200
k1ex = k1
k2ex = k2
k3ex = k3
k1in = 0.0
k2in = 0.0
k3in = 0.0
gamma1 = tau * 0.1
gamma2 = tau * 0.1

# phases
phi1 = tau/3.0
phi2 = -tau/3.0
phi3 = 0.0

nm = 800.0

def matrices(beta):
    # detunings
    delta1 = -beta*gamma1
    delta2 = beta*gamma2
    # couplings 
    C = 2 * beta/np.sqrt(3.0) - 1./3.0
    g11 = np.sqrt(k1 * gamma1 * C / 4.0)
    g21 = np.sqrt(k2 * gamma1 * C / 4.0)
    g31 = np.sqrt(k3 * gamma1 * C / 4.0)
    g12 = np.sqrt(k1 * gamma2 * C / 4.0)
    g22 = np.sqrt(k2 * gamma2 * C / 4.0)
    g32 = np.sqrt(k3 * gamma2 * C / 4.0)

    M = np.matrix([
        [-k1/2.0, 0, 0, -1j*np.exp(1j*phi1)*g11, -1j*g12],
        [0, -k2/2.0, 0, -1j*np.exp(1j*phi2)*g21, -1j*g22],
        [0, 0, -k3/2.0, -1j*np.exp(1j*phi3)*g31, -1j*g32],
        [-1j*np.exp(-1j*phi1)*g11, -1j*np.exp(-1j*phi2)*g21, 
            -1j*np.exp(-1j*phi3)*g31, 1j*delta1 - gamma1/2.0, 0],
        [-1j*g12, -1j*g22, -1j*g32, 0, 1j*delta2 - gamma2/2.0],
        ])

    L = np.matrix([
        [np.sqrt(k1ex), 0, 0, np.sqrt(k1in), 0, 0, 0, 0],
        [0, np.sqrt(k2ex), 0, 0, np.sqrt(k2in), 0, 0, 0],
        [0, 0, np.sqrt(k3ex), 0, 0, np.sqrt(k3in), 0, 0],
        [0, 0, 0, 0, 0, 0, np.sqrt(gamma1), 0],
        [0, 0, 0, 0, 0, 0, 0, np.sqrt(gamma2)],
        ])

    return M, L

def S_matrix(f, beta):
    om = f * tau
    M, L = matrices(beta)
    S = np.identity(8) + L.T * np.linalg.inv(M + 1j* om * np.identity(5)) * L
    return S

def S_matrix_coop(f, coop):
    beta = np.sqrt(3.0)*(coop + 1./3.)/2.0
    return S_matrix(f, beta)

def noiseout(S):
    norm = lambda x: np.abs(x)**2
    nMW = 0.5 * (norm(S[0,0]) + norm(S[0,1]) + norm(S[0,2]) + norm(S[0,3]) + norm(S[0,4]) + norm(S[0,5])) 
    nMec = (0.5+nm) * (norm(S[0,6]) + norm(S[0,7]))
    return nMW + nMec


